<?php
/**
 * Draw Calendar
 *
 * @param	int		$nMth	One-digit integer of current month (ie. 1, 2, 3...12)
 * @param	int		$year	Four-digit integer of current year	 (ie. 2013)
 * @param	array	$headings	Array of day names (ie. array("Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"))
 * @param	string	$month	Name of current month (ie. January)
 *
 * @author	David Walsh
 * @link 	http://davidwalsh.name/php-calendar
 *
 * PLEASE NOTE:
 *
 * I added lines 50 to 59 to add a unique id to each hyperlink for each day.
 */

function draw_calendar($nMth,$year,$headings,$month) {
	$today = date("j");
	/* draw table */
	$calendar = "<table class='calendar fluid large-margin-bottom'><caption><span class='cal-prev'>◄</span><a href='#' class='cal-next'>►</a>$month $year</caption>";

	/* table headings */
	$calendar.= '<thead><tr><th scope="col">'.implode('</th><th scope="col">',$headings).'</th></tr></thead>';

	/* days and weeks vars now ... */
	$running_day = date('w',mktime(0,0,0,$nMth,1,$year));		// first day of curent month, 0 to 6
	$prev = date('t',mktime(0, 0, 0, $nMth-1,1,$year));				// number of days in prev month
	$start = $prev-$running_day+1;											// first day to display from the prev month last days
	$days_in_month = date('t',mktime(0,0,0,$nMth,1,$year));
	$days_in_this_week = 1;
	$day_counter = 0;
	//$dates_array = array();

	/* row for week one */
	$calendar.= "<tr>";

	/* print "blank" days until the first of the current week */
	for ($x = 0; $x < $running_day; $x++):
		$calendar.= '<td class="prev-month"><span class="cal-day">'.$start.'</span></td>';
		$days_in_this_week++;
		$start++;
	endfor;

	/* keep going with days.... */
	for ($list_day = 1; $list_day <= $days_in_month; $list_day++):
		$tem = ($running_day == 0 || $running_day == 6);
		if ($list_day == $today)
		{$tem ? $calendar.= '<td class="today week-end">' : $calendar.= '<td class="today">';}
		else
		{$tem ? $calendar.= '<td class="week-end">' : $calendar.= "<td>";}

		/**
			* Assign a unique id to the day number. This unique id will be
			* used by jQuery to locate events from the database that are
			* on this day. The unique id is the timestamp for the first minute
			* of $list_day of $nMth of $year.
			*
			* @author Josh Lockhart, http://www.newmediacampaigns.com, lines 40-41
			*/
		// $timestamp = mktime(0,0,0,$nMth,$list_day,$year);
		// $calendar.= '<div><a id="'.$timestamp.'" href="#"><span class="cal-day">'.$list_day.'</span></a></div>';

		$calendar.= "<span class='cal-day'>".$list_day."</span>";
		$posDiw = $days_in_this_week;
			
		$calendar.= "</td>";
		if ($running_day == 6):
			$calendar.= '</tr>';
			if (($day_counter+1) != $days_in_month):
				$calendar.= '<tr>';
			endif;
			$running_day = -1;
			$days_in_this_week = 0;
		endif;
		$days_in_this_week++; $running_day++; $day_counter++;
	endfor;

	/* finish the rest of the days in the week */
	if ($posDiw < 7):
		$start=1;
		for($x = 1; $x <= (8 - $days_in_this_week); $x++):
			$calendar.= '<td class="prev-month"><span class="cal-day">'.$start.'</span></td>';
			$start++;
		endfor;
	endif;

	/* final row */
	$calendar.= '</tr></table>';

	/* all done, return result */
	return $calendar;
}
?>
